summaryrefslogtreecommitdiff
path: root/includes
diff options
context:
space:
mode:
authorfisharebest <fisharebest@gmail.com>2010-04-26 20:26:24 +0000
committerfisharebest <fisharebest@gmail.com>2010-04-26 20:26:24 +0000
commit3269cbd3d4d7dfe7c8f60516b566ebb2ac25823a (patch)
tree3a4dee60f2a7220a8c55f21b8a9d40a729f6fbb4 /includes
parentb329be8841aceed6551b9bfc0cb5436f83a57e35 (diff)
downloadwebtrees-3269cbd3d4d7dfe7c8f60516b566ebb2ac25823a.tar.gz
webtrees-3269cbd3d4d7dfe7c8f60516b566ebb2ac25823a.tar.bz2
webtrees-3269cbd3d4d7dfe7c8f60516b566ebb2ac25823a.zip
Diffstat (limited to 'includes')
-rw-r--r--includes/authentication.php8
-rw-r--r--includes/functions/functions_export.php12
-rw-r--r--includes/functions/functions_privacy.php10
-rw-r--r--includes/session.php2
-rw-r--r--includes/session_spider.php2
5 files changed, 17 insertions, 17 deletions
diff --git a/includes/functions/functions_export.php b/includes/functions/functions_export.php
index 984a1b99ad..5a0287c7af 100644
--- a/includes/functions/functions_export.php
+++ b/includes/functions/functions_export.php
@@ -271,8 +271,8 @@ function export_gedcom($gedcom, $gedout, $exportOptions) {
$export_user_id = createTempUser($tempUserID, $exportOptions['privatize'], $gedcom); // Create a temporary userid
// Temporarily become this user
- $_SESSION["org_user"]=$_SESSION["pgv_user"];
- $_SESSION["pgv_user"]=$tempUserID;
+ $_SESSION["org_user"]=$_SESSION["wt_user"];
+ $_SESSION["wt_user"]=$tempUserID;
}
$head=gedcom_header($gedcom);
@@ -364,7 +364,7 @@ function export_gedcom($gedcom, $gedout, $exportOptions) {
fwrite($gedout, $buffer."0 TRLR".WT_EOL);
if ($exportOptions['privatize']!='none') {
- $_SESSION["pgv_user"]=$_SESSION["org_user"];
+ $_SESSION["wt_user"]=$_SESSION["org_user"];
delete_user($export_user_id);
AddToLog("deleted dummy user -> {$tempUserID} <-", 'auth');
}
@@ -400,8 +400,8 @@ function export_gramps($gedcom, $gedout, $exportOptions) {
$export_user_id = createTempUser($tempUserID, $exportOptions['privatize'], $gedcom); // Create a temporary userid
// Temporarily become this user
- $_SESSION["org_user"]=$_SESSION["pgv_user"];
- $_SESSION["pgv_user"]=$tempUserID;
+ $_SESSION["org_user"]=$_SESSION["wt_user"];
+ $_SESSION["wt_user"]=$tempUserID;
}
$geDownloadGedcom=new GEDownloadGedcom();
@@ -450,7 +450,7 @@ function export_gramps($gedcom, $gedout, $exportOptions) {
fwrite($gedout,$geDownloadGedcom->dom->saveXML());
if ($exportOptions['privatize']!='none') {
- $_SESSION["pgv_user"]=$_SESSION["org_user"];
+ $_SESSION["wt_user"]=$_SESSION["org_user"];
delete_user($export_user_id);
AddToLog("deleted dummy user -> {$tempUserID} <-", 'auth');
}
diff --git a/includes/functions/functions_privacy.php b/includes/functions/functions_privacy.php
index f11a9832bd..3a22cb30e4 100644
--- a/includes/functions/functions_privacy.php
+++ b/includes/functions/functions_privacy.php
@@ -351,7 +351,7 @@ function displayDetailsById($pid, $type = "INDI", $sitemap = false) {
global $GEDCOM;
$ged_id=get_id_from_gedcom($GEDCOM);
- if ($_SESSION["pgv_user"]==WT_USER_ID) {
+ if ($_SESSION["wt_user"]==WT_USER_ID) {
// Normal operation
$pgv_GEDCOM = WT_GEDCOM;
$pgv_GED_ID = WT_GED_ID;
@@ -667,7 +667,7 @@ function showLivingNameById($pid) {
global $GEDCOM;
global $SHOW_LIVING_NAMES, $person_privacy, $user_privacy;
- if ($_SESSION["pgv_user"]==WT_USER_ID) {
+ if ($_SESSION["wt_user"]==WT_USER_ID) {
// Normal operation
$pgv_USER_NAME = WT_USER_NAME;
$pgv_USER_ACCESS_LEVEL = WT_USER_ACCESS_LEVEL;
@@ -717,7 +717,7 @@ function showFact($fact, $pid, $type='INDI') {
global $GEDCOM;
global $global_facts, $person_facts, $SHOW_SOURCES;
- if ($_SESSION["pgv_user"]==WT_USER_ID) {
+ if ($_SESSION["wt_user"]==WT_USER_ID) {
// Normal operation
$pgv_USER_ACCESS_LEVEL = WT_USER_ACCESS_LEVEL;
} else {
@@ -768,7 +768,7 @@ function showFactDetails($fact, $pid) {
global $GEDCOM;
global $global_facts, $person_facts;
- if ($_SESSION["pgv_user"]==WT_USER_ID) {
+ if ($_SESSION["wt_user"]==WT_USER_ID) {
// Normal operation
$pgv_USER_ACCESS_LEVEL = WT_USER_ACCESS_LEVEL;
} else {
@@ -966,7 +966,7 @@ function FactEditRestricted($pid, $factrec) {
* @return int Allowed or not allowed
*/
function FactViewRestricted($pid, $factrec) {
- if ($_SESSION['pgv_user']==WT_USER_ID) {
+ if ($_SESSION['wt_user']==WT_USER_ID) {
// Normal operation
$pgv_GED_ID = WT_GED_ID;
$pgv_USER_GEDCOM_ADMIN = WT_USER_GEDCOM_ADMIN;
diff --git a/includes/session.php b/includes/session.php
index 38f9058cf4..f2b160dbf1 100644
--- a/includes/session.php
+++ b/includes/session.php
@@ -417,7 +417,7 @@ CheckPageViews();
$show_context_help = '';
if (!empty($_REQUEST['show_context_help'])) $show_context_help = $_REQUEST['show_context_help'];
if (!isset($_SESSION['show_context_help'])) $_SESSION['show_context_help'] = $SHOW_CONTEXT_HELP;
-if (!isset($_SESSION['pgv_user'])) $_SESSION['pgv_user'] = '';
+if (!isset($_SESSION['wt_user'])) $_SESSION['wt_user'] = '';
if (isset($SHOW_CONTEXT_HELP) && $show_context_help==='yes') $_SESSION['show_context_help'] = true;
if (isset($SHOW_CONTEXT_HELP) && $show_context_help==='no') $_SESSION['show_context_help'] = false;
if (!isset($USE_THUMBS_MAIN)) $USE_THUMBS_MAIN = false;
diff --git a/includes/session_spider.php b/includes/session_spider.php
index f5068ac495..ed88c72746 100644
--- a/includes/session_spider.php
+++ b/includes/session_spider.php
@@ -400,7 +400,7 @@ if(!empty($SEARCH_SPIDER)) {
if(isset($_SERVER['HTTP_ACCEPT_LANGUAGE']))
$_SESSION['last_spider_lang'] = $_SERVER['HTTP_ACCEPT_LANGUAGE'];
- $_SESSION['pgv_user'] = ""; // Don't allow search engine into user/admin mode.
+ $_SESSION['wt_user'] = ""; // Don't allow search engine into user/admin mode.
}
?>
diff --git a/includes/authentication.php b/includes/authentication.php
index 3555b6d997..b271df1e1a 100644
--- a/includes/authentication.php
+++ b/includes/authentication.php
@@ -48,7 +48,7 @@ define('WT_AUTHENTICATION_PHP', '');
*
* This function takes the given <var>$username</var> and <var>$password</var> and authenticates
* them against the database. The passwords are encrypted using the crypt() function.
* The username is stored in the <var>$_SESSION["pgv_user"]</var> session variable.
* @param string $user_name the username for the user attempting to login
* @param string $password the plain text password to test
* @param boolean $basic true if the userName and password were retrived via Basic HTTP authentication. Defaults to false. At this point, this is only used for logging
@@ -67,7 +67,7 @@ function authenticateUser($user_name, $password, $basic=false) {
set_user_setting($user_id, 'loggedin', 'Y');
//-- reset the user's session
$_SESSION = array();
- $_SESSION['pgv_user'] = $user_id;
+ $_SESSION['wt_user'] = $user_id;
AddToLog(($basic ? 'Basic HTTP Authentication' :'Login'). ' Successful', 'auth');
return $user_id;
}
@@ -139,10 +139,10 @@ function userUpdateLogin($user_id) {
*/
function getUserId() {
- if (empty($_SESSION['pgv_user'])) {
+ if (empty($_SESSION['wt_user'])) {
return 0;
} else {
- return $_SESSION['pgv_user'];
+ return $_SESSION['wt_user'];
}
}
@@ -48,7 +48,7 @@ define('WT_AUTHENTICATION_PHP', '');
* This function takes the given <var>$username</var> and <var>$password</var> and authenticates
* them against the database. The passwords are encrypted using the crypt() function.
- * The username is stored in the <var>$_SESSION["pgv_user"]</var> session variable.
+ * The username is stored in the <var>$_SESSION["wt_user"]</var> session variable.
* @param string $user_name the username for the user attempting to login
* @param string $password the plain text password to test